==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/i18n/LineBreakHyphenationOptions.hpp <==
#ifndef _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HPP_
#define _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HDL_
#include "com/sun/star/i18n/LineBreakHyphenationOptions.hdl"
#endif

#ifndef _COM_SUN_STAR_BEANS_PROPERTYVALUES_HPP_
#include "com/sun/star/beans/PropertyValues.hpp"
#endif
#ifndef _COM_SUN_STAR_LINGUISTIC2_XHYPHENATOR_HPP_
#include "com/sun/star/linguistic2/XHyphenator.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace i18n {

inline LineBreakHyphenationOptions::LineBreakHyphenationOptions() SAL_THROW( () )
    : rHyphenator()
    , aHyphenationOptions()
    , hyphenIndex(0)
{
}

inline LineBreakHyphenationOptions::LineBreakHyphenationOptions(const ::com::sun::star::uno::Reference< ::com::sun::star::linguistic2::XHyphenator >& rHyphenator_, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& aHyphenationOptions_, const ::sal_Int32& hyphenIndex_) SAL_THROW( () )
    : rHyphenator(rHyphenator_)
    , aHyphenationOptions(aHyphenationOptions_)
    , hyphenIndex(hyphenIndex_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::i18n::LineBreakHyphenationOptions const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.i18n.LineBreakHyphenationOptions");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/i18n/LineBreakHyphenationOptions.hpp <==
#ifndef _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HPP_
#define _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HDL_
#include "com/sun/star/i18n/LineBreakHyphenationOptions.hdl"
#endif

#ifndef _COM_SUN_STAR_BEANS_PROPERTYVALUES_HPP_
#include "com/sun/star/beans/PropertyValues.hpp"
#endif
#ifndef _COM_SUN_STAR_LINGUISTIC2_XHYPHENATOR_HPP_
#include "com/sun/star/linguistic2/XHyphenator.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace i18n {

inline LineBreakHyphenationOptions::LineBreakHyphenationOptions() SAL_THROW( () )
    : rHyphenator()
    , aHyphenationOptions()
    , hyphenIndex(0)
{
}

inline LineBreakHyphenationOptions::LineBreakHyphenationOptions(const ::com::sun::star::uno::Reference< ::com::sun::star::linguistic2::XHyphenator >& rHyphenator_, const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& aHyphenationOptions_, const ::sal_Int32& hyphenIndex_) SAL_THROW( () )
    : rHyphenator(rHyphenator_)
    , aHyphenationOptions(aHyphenationOptions_)
    , hyphenIndex(hyphenIndex_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace i18n {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::i18n::LineBreakHyphenationOptions const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.i18n.LineBreakHyphenationOptions");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::i18n::LineBreakHyphenationOptions const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::i18n::LineBreakHyphenationOptions >::get();
}

#endif // _COM_SUN_STAR_I18N_LINEBREAKHYPHENATIONOPTIONS_HPP_
